@@ -2,8 +2,8 @@
 
 ;; Author: Siddhartha Kasivajhula <sid@countvajhula.com>
 ;; URL: https://github.com/countvajhula/lithium
-;; Package-Version: 0.1.1
-;; Package-Revision: v0.1.1-0-g8d97cec32fe7
+;; Package-Version: 20250703.243
+;; Package-Revision: 5ed65cba5ff3
 ;; Package-Requires: ((emacs "25.1"))
 ;; Keywords: convenience, emulations, lisp, tools
 
@@ -113,11 +113,7 @@ appropriate times."
            ;; It's possible that the `action' could itself already
            ;; have exited the mode, so we first check whether the mode
            ;; is active before attempting to exit.
-           (when ,mode
-             (run-hooks ',pre-exit)
-             (funcall #',mode -1)
-             ;; run post-exit hook "intrinsically"
-             (run-hooks ',post-exit))))
+           (lithium-exit-mode ',mode)))
     `(lambda ()
        (interactive)
        (condition-case err
@@ -148,6 +144,7 @@ If EXIT is true, exit the mode after running the command.
 If `exit' is missing, then it's an ordinary binding of key to action,
 but if exit is present and set to true, then also exit the MODE after
 performing the action."
+  (declare (indent 1))
   (let ((keymap (intern
                  (concat (if (lithium-global-mode-p mode)
                              "local-"
@@ -174,6 +171,7 @@ performing the action."
 
 (defmacro lithium-define-keys (mode keyspec)
   "Bind keybindings in KEYSPEC in MODE."
+  (declare (indent 1))
   `(progn
      ,@(mapcar (apply-partially #'lithium--define-key-from-spec mode) keyspec)))
 
@@ -517,6 +515,8 @@ DOCSTRING, KEYMAP-SPEC and BODY are forwarded to
             #'lithium-evaluate-overriding-map)
   (add-hook 'window-configuration-change-hook
             #'lithium-evaluate-overriding-map)
+  (add-hook 'post-command-hook
+            #'lithium-evaluate-overriding-map)
   (advice-add #'internal-push-keymap :before #'lithium--suspend-overriding-map-advice))
 
 (defun lithium-disable ()
@@ -527,6 +527,8 @@ DOCSTRING, KEYMAP-SPEC and BODY are forwarded to
                #'lithium-evaluate-overriding-map)
   (remove-hook 'window-configuration-change-hook
                #'lithium-evaluate-overriding-map)
+  (remove-hook 'post-command-hook
+               #'lithium-evaluate-overriding-map)
   (advice-remove #'internal-push-keymap #'lithium--suspend-overriding-map-advice))
 
 ;;;###autoload
